@@ -2,6 +2,6 @@
 
 """jcast.__main__: executed when jcast directory is called as script."""
 
-from .main import main
+from jcast.main import main
 
 main()
\ No newline at end of file
