@@ -8,13 +8,8 @@ import logging
 from functools import partial
 
 import tqdm
-from sklearn.mixture import GaussianMixture
-from sklearn.preprocessing import PowerTransformer
-import numpy as np
-import matplotlib.pyplot as plt
-import scipy.stats as stats
 
-from jcast import params, fates
+from jcast import params, fates, model
 from jcast.junctions import Junction, RmatsResults
 from jcast.annots import ReadAnnotations, ReadGenome
 from jcast.sequences import Sequence
@@ -88,68 +83,32 @@ def runjcast(args):
 
         main_log.info('The -m flag is set. The modeled read count will override -r --read values.')
 
-        tot = rmats_results.rmats_mxe.append(rmats_results.rmats_se).append(rmats_results.rmats_ri).append(
-            rmats_results.rmats_a5ss).append(rmats_results.rmats_a3ss).copy()
-        junctions = [Junction(**tot.iloc[i].to_dict()) for i in range(len(tot))]
+        # Make a numpy array of all junction SJC sum counts
+        rmats_results.get_junction_count_array()
 
-        # Array of junction sum read counts
-        matrix_X = np.array([[j.sum_sjc + 1] for j in junctions])
-        pt = PowerTransformer(method='box-cox')
-        pt.fit(matrix_X)
-        matrix_X_trans = pt.transform(matrix_X)
-
-        gmm = GaussianMixture(n_components=2,
-                              covariance_type='diag',
-                              random_state=1,
-                              ).fit(matrix_X_trans)
-
-        # Sort the classification components so the high-read distribution appears second
-        order = gmm.means_.argsort(axis=0)[:, 0]
-        gmm.means_ = gmm.means_[order]
-        gmm.covariances_ = gmm.covariances_[order]
-        gmm.weights_ = gmm.weights_[order]
-        gmm.precisions_ = gmm.precisions_[order]
-        gmm.precisions_cholesky_ = gmm.precisions_cholesky_[order]
-
-        weights = gmm.weights_
-        means = gmm.means_
-        covars = gmm.covariances_
-
-        # Get the decision boundary (minimum count required to be predicted as second predicted class)
-        # TODO: catch errors where model may fail and min_count remains 1
-        min_count = 1
-        # Loop only from 1 count to the mean of the second distribution
-        for i in range(1, round(pt.inverse_transform([gmm.means_[1]])[0][0])):
-            dist = gmm.predict(pt.transform(np.array([[i]])))
-            if dist == [1]:
-                min_count = i
-                break
-
-        # Plot out the model figure and decision boundary
-        fig, ax = plt.subplots(constrained_layout=True)
-        ax.hist(matrix_X_trans, bins=50, histtype='bar', density=True, ec='red', alpha=0.5)
-        plt.style.use('seaborn-white')
-        ax.set_xlabel('Box-Cox transformed total skipped junction counts')
-        ax.set_ylabel('Frequency')
-        ax.set_title('Skipped junction count distributions')
-        tcks, values = plt.xticks()
-        new_tcks = np.int_(np.sort(pt.inverse_transform(np.array([[t] for t in tcks])).ravel()))
-
-        # Second axis for untransformed reads
-        ax2 = ax.twiny()
-        ax2.set_xlim(ax.get_xlim())
-        ax2.set_xticks(tcks[1:-1])
-        ax2.set_xlabel('Untransformed total splice junction read counts')
-        ax2.set_xticklabels(new_tcks[1:-1])
-        ax2.axvline(linewidth=4, ls='--', color='blue', x=pt.transform(np.array([[min_count]])))
-
-        f_axis = matrix_X_trans.copy().ravel()
-        f_axis.sort()
-        ax.plot(f_axis, weights[0] * stats.norm.pdf(f_axis, means[0], np.sqrt(covars[0])).ravel(), c='red')
-        ax.plot(f_axis, weights[1] * stats.norm.pdf(f_axis, means[1], np.sqrt(covars[1])).ravel(), c='blue')
-
-        plt.savefig(fname=os.path.join(write_dir, 'model.png'))
+        ln_sjc, best_mix_model, min_count = model.general_mixture_model(sum_sjc_array=rmats_results.sum_sjc_array)
+        model.plot_general_mixture_model(
+            ln_sjc,
+            best_mix_model,
+            min_count,
+            write_dir=write_dir,
+            filename='model',
+            )
+        
+        # Gaussian mixture model implementation
+        """
+        pt, gmm, min_count = model.gaussian_mixture(sum_sjc_array=rmats_results.sum_sjc_array)
 
+        # Plot out the model
+        model.plot_model(sum_sjc_array=rmats_results.sum_sjc_array,
+                         pt=pt,
+                         gmm=gmm,
+                         min_count=min_count,
+                         write_dir=write_dir,
+                         filename='model',
+                         )
+        """
+    # If the m flag is not set, use the r argument value as min count
     else:
         min_count = args.read
     #
@@ -218,6 +177,7 @@ def _translate_one(junction,
                    ):
     """ get coordinate and translate one junction; arguments are passed through partial from main"""
 
+    print(f'Gene Symbol: {junction.gene_symbol} ID: {junction.gene_id}')
     #
     # trim slice coordinates by translation starts and ends
     #
@@ -253,7 +213,7 @@ def _translate_one(junction,
 
     # If the -r argument is set directly and the -m flag is not, use the -r integer for count filtering
     # If the -m flag is set, use the modeled count for filtering
-    if (not args.model and junction.sum_sjc < args.read) or (args.model and junction.sum_sjc < pred_bound):
+    if (not args.model and junction.sum_sjc <= args.read) or (args.model and junction.sum_sjc <= pred_bound):
         #
         # If the canonical flag is set, append the canonical
         # Sp to the gene_canonical output even if none of the transcript slices are stitchable
@@ -270,7 +230,7 @@ def _translate_one(junction,
     # this removes junctions that are inconsistently found on both replicates.
     #
     q_lo, q_hi = args.qvalue
-    if not q_lo < junction.fdr < q_hi:
+    if not q_lo <= junction.fdr <= q_hi:
 
         # Write canonical anyhow if the canonical flag is set.
         if args.canonical:
@@ -458,6 +418,11 @@ def main():
                         nargs=2,
                         default=[0, 1],
                         type=float)
+    # DEVELOPMENT ARGUMENT, Should be deleted when a default distribution - Gamma or LogNorm - is determined.
+    parser.add_argument("--g_or_ln",
+                        help="Switch on distribution to use for low end of histogram, 0 for Gamma, anything else for LogNorm",
+                        default=0,
+                        type=int)
 
     parser.set_defaults(func=runjcast)
 
