@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-""" Tests """
+""" Tests for gtf related functionalities """
 
 
 import unittest
@@ -21,7 +21,6 @@ class AnnotationTest(unittest.TestCase):
 
         global test_data_loc, human_gtf_loc, rat_gtf_loc
 
-
         test_data_loc = os.path.join('tests', 'data')
         human_gtf_loc = os.path.join(test_data_loc, 'genome', 'Homo_sapiens.GRCh38.89.chromosome.15.gtf')
         rat_gtf_loc = os.path.join(test_data_loc, 'genome', 'Rattus_norvegicus.Rnor_6.0.100.chromosome.12.gtf')
@@ -53,7 +52,7 @@ class AnnotationTest(unittest.TestCase):
         pass
 
     def test_human_tss(self):
-        """ finds the translation start of a human gene """
+        """ tests finding the translation start of a human gene """
 
         human_gtf = ReadAnnotations(human_gtf_loc)
         human_gtf.read_gtf()
@@ -77,7 +76,7 @@ class AnnotationTest(unittest.TestCase):
         pass
 
     def test_rat_tss(self):
-        """ finds the translation start of a rat gene """
+        """ tests finding the translation start of a rat gene """
 
         rat_gtf = ReadAnnotations(rat_gtf_loc)
         rat_gtf.read_gtf()
@@ -93,5 +92,3 @@ class AnnotationTest(unittest.TestCase):
         self.assertGreater(tx0, 0)
 
         pass
-
-
